searchData={"items":[{"type":"task","title":"mix version","doc":"This module implements a mix task whose main purpose is to update the version\nnumber of an Elixir application, with extra steps such as committing a git\ntag.\n\n\n\nThis is a simple tool to automatically update the version number of an Elixir\nproject in the `mix.exs`, commit the change and create and create a git tag\nbased on the new version.\n\nCheck out [version_tasks](https://hex.pm/packages/version_tasks) for a more\nversatile solution.","ref":"Mix.Tasks.Version.html"},{"type":"task","title":"Installation - mix version","doc":"Although this tool can be set as a dependency in you mix projects, is is rather intended to be used as a globally available command line tool.\n\n```bash\nmix archive.install hex mix_version\n```","ref":"Mix.Tasks.Version.html#module-installation"},{"type":"task","title":"Breaking changes in version 2 - mix version","doc":"The v2 is a partial rewrite where most checks are run before attempting to make\nany modification for the project. A few changes to how the tool should be used\nwere implemented:\n\n* The configuration of the tool from the config files is not supported anymore.\n  This is to support the tool as a globally installed archive. When\n  `mix_version` is not listed in the dependencies, Elixir would warn if a\n  project contains configuration for an unknown application.\n* The new configuration is provided by listing a `:versioning` from the\n  `project/0` callback of the `mix.exs` file.\n* The `--git-only` option was dropped, as the tool will warn and prompt if some\n  files are not checked in, allowing to fix those issues before any change is\n  made to the `mix.exs` file and any commit/tag is created.\n* Any unchecked change to the `mix.exs` file will prevent the tool to run.\n* The `:annotate` option is now `true` by default, creating annotated tags.","ref":"Mix.Tasks.Version.html#module-breaking-changes-in-version-2"},{"type":"task","title":"Configuration - mix version","doc":"The configuration for v2 can be provided under `:versioning` from the\n`project/0` callback of the project file:\n\n```elixir\n# in mix.exs\n\ndef project do\n  [\n    app: :my_app,\n    version: \"1.2.3\",\n    # ...\n    versioning: versioning()\n  ]\nend\n\ndefp versioning do\n  [\n    tag_prefix: \"release-\",\n    commit_msg: \"new version: %s\",\n    annotation: \"tag release-%s created with mix_version\",\n    annotate: true\n  ]\nend\n```\n\nIn the commit message and annotation, any occurence of `%s` will be replaced by\nthe new version number. The presence of `%s` is not mandatory.\n\nConfiguration can be overriden by command line options. For instance, if\n`:annotate` is set to `true` in configuration, you can use the `--no-annotate`\nCLI flag to force it to be `false`.\n\n\nThe following sample configuration is now unsupported and will be ignored.\n\n```elixir\nimport Config\n\n# UNSUPPORTED AS OF v2.0.0\nconfig :mix_version,\n  tag_prefix: \"release-\",\n  commit_msg: \"new version: %s\",\n  annotation: \"tag release-%s created with mix_version\",\n  annotate: true\n```\n\n\n#","ref":"Mix.Tasks.Version.html#module-configuration"},{"type":"task","title":"Default configuration - mix version","doc":"```elixir\nannotate:   true\ncommit_msg: \"new version %s\"\nannotation: \"new version %s\"\ntag_prefix: \"v\"\n```","ref":"Mix.Tasks.Version.html#module-default-configuration"},{"type":"task","title":"Usage - mix version","doc":"Call the command from within a mix project. With no options, you will be\nprompted for the new version number.\n\n```bash\nmix version [options]\n```\n\n\n#","ref":"Mix.Tasks.Version.html#module-usage"},{"type":"task","title":"Options - mix version","doc":"Versions managed by Elixir follow the `MAJOR.MINOR.PATCH` scheme, with\noptionnaly a pre-release tag as in `1.0.0-rc2`.\n\n```text\n-M, --major        boolean. Bump to a new major version.\n-m, --minor        boolean. Bump to a new minor version.\n-p, --patch        boolean. Bump the patch version.\n-a, --annotate     boolean. Create an annotated git tag.\n-A, --annotation   string. Define the tag annotation message, with all '%s' replaced by the new VSN.\n-c, --commit-msg   string. Define the commit message, with all '%s' replaced by the new VSN.\n-n, --new-version  string. Set the new version number.\n-x, --tag-prefix   string. Define the tag prefix.\n\n```\n\nWhen using the options to bump a part of the version, a pre-release tag will be\ndropped for a major or minor bump, whereas a patch bump will only remove this\npre-release tag and keep the current patch number.\n\n```text\nBump patch:\n  1.2.3-rc1  ->  1.2.3\n  1.2.3      ->  1.2.4\n\nBump minor:\n  1.2.3-rc1  ->  1.3.0\n  1.2.3      ->  1.3.0\n\nBump major:\n  1.2.3-rc1  ->  2.0.0\n  1.2.3      ->  2.0.0\n```","ref":"Mix.Tasks.Version.html#module-options"},{"type":"task","title":"Usage - mix version","doc":"mix version [options]","ref":"Mix.Tasks.Version.html#module-usage"},{"type":"task","title":"Options - mix version","doc":"* `-a`, `--annotate` - Create an annotated git tag.\n* `-A`, `--annotation` - Define the tag annotation message, with all '%s' replaced by the new VSN.\n* `-c`, `--commit-msg` - Define the commit message, with all '%s' replaced by the new VSN.\n* `-i`, `--info` - Only outputs the current version and stops. Ignores all other options.\n* `-M`, `--major` - Bump to a new major version.\n* `-m`, `--minor` - Bump to a new minor version.\n* `-n`, `--new-version` - Set the new version number.\n* `-p`, `--patch` - Bump the patch version.\n* `-k`, `--tag-current` - Commit and tag with the current version.\n* `-x`, `--tag-prefix` - Define the tag prefix.\n* `--help` - Displays this help.","ref":"Mix.Tasks.Version.html#module-options"},{"type":"module","title":"MixVersion.CLI","doc":"Implementation of the CLI with `CliMate`.","ref":"MixVersion.CLI.html"},{"type":"function","title":"MixVersion.CLI.color/2","doc":"Outputs `iodata` in the current shell, wrapped with formatting\ninformation, such as `[color, iodata, :default_color]`.\n\n`color` should be a `IO.ANSI.format/2` compatible atom.","ref":"MixVersion.CLI.html#color/2"},{"type":"function","title":"MixVersion.CLI.debug/1","doc":"Outputs `iodata` in the current shell, formatted with cyan color.","ref":"MixVersion.CLI.html#debug/1"},{"type":"function","title":"MixVersion.CLI.error/1","doc":"Outputs `iodata` to `stderr` in the current shell, formatted with bright\nred color.","ref":"MixVersion.CLI.html#error/1"},{"type":"function","title":"MixVersion.CLI.format_usage/2","doc":"Returns a standard \"usage\" documentation block describing the different\noptions of the given command.\n\n#","ref":"MixVersion.CLI.html#format_usage/2"},{"type":"function","title":"Options - MixVersion.CLI.format_usage/2","doc":"* `:format` - If `:moduledoc`, the formatted usage will be compatible for\n  embedding in a `@moduledoc` attribute. Any other value will generate a\n  simple terminal styled text. Defaults to `:cli`.","ref":"MixVersion.CLI.html#format_usage/2-options"},{"type":"function","title":"MixVersion.CLI.halt/1","doc":"Stops the execution of the Erlang runtime, with a given return code.\n\nIf not provided, the return code will be `0`.","ref":"MixVersion.CLI.html#halt/1"},{"type":"function","title":"MixVersion.CLI.halt_error/2","doc":"Combines `error/1` then `halt/1`. Halts the Erlang runtime with a `1`\nreturn code by default.","ref":"MixVersion.CLI.html#halt_error/2"},{"type":"function","title":"MixVersion.CLI.halt_success/1","doc":"Combines `success/1` then `halt/1`. Halts the Erlang runtime with a `0`\nreturn code.","ref":"MixVersion.CLI.html#halt_success/1"},{"type":"function","title":"MixVersion.CLI.parse/2","doc":"Accepts the command line arguments and the definition of a command\n(options, arguments, and metadata) and returns a parse result with values\nextracted from the command line arguments.\n\n#","ref":"MixVersion.CLI.html#parse/2"},{"type":"function","title":"Defining options - MixVersion.CLI.parse/2","doc":"Options definitions is a `Keyword` whose keys are the option name, and\nvalues are the options parameters. Note that keys with underscores like\n`some_thing` define options in kebab case like `--some-thing`.\n\nThe following parameters are available:\n\n- `:type` - Can be either `:boolean`, `:integer` or `:string`. The default\n  value is `:string`.\n- `:short` - Defines the shortcut for the option, for instance `-p`\n  instead of `--port`.\n- `:default` - Defines the default value if the corresponding option is\n  not defined in `argv`.See \"Default values\" below.\n- `:doc` - Accepts a string that will be used when formatting the usage\n  block for the command.\n\nNote that the `:help` option is always defined and cannot be overridden.\n\n#","ref":"MixVersion.CLI.html#parse/2-defining-options"},{"type":"function","title":"Default values - MixVersion.CLI.parse/2","doc":"Default values can be omitted, in that case, the option will not be\npresent at all if not provided in the command line.\n\nWhen defined, a default value can be:\n\n* A raw value, that is anything that is not a function. This value will be\n  used as the default value.\n* A function of arity zero. This function will be called when the option\n  is not provided in the command line and the result value will be used as\n  the default value. For instance `fn -> 123 end` or `&default_age/0`.\n* A function of arity one. This function will be called with the option\n  key as its argument. For instance, passing `&default_opt/1` as the\n  `:default` for an option definition allow to define the following\n  function:\n\n      defp default_opt(:port), do: 4000\n      defp default_opt(:scheme), do: \"http\"\n\n#","ref":"MixVersion.CLI.html#parse/2-default-values"},{"type":"function","title":"Options examples - MixVersion.CLI.parse/2","doc":"iex> {:ok, result} = parse(~w(--who joe), [options: [who: [type: :string]]])\n    iex> result.options.who\n    \"joe\"\n\n    iex> {:ok, result} = parse(~w(--who joe), [options: [who: []]])\n    iex> result.options.who\n    \"joe\"\n\n    iex> {:ok, result} = parse(~w(--port 4000), [options: [port: [type: :integer]]])\n    iex> result.options.port\n    4000\n\n    iex> {:ok, result} = parse(~w(-p 4000), [options: [port: [type: :integer, short: :p]]])\n    iex> result.options.port\n    4000\n\n    iex> parse(~w(--port nope), [options: [port: [type: :integer]]])\n    {:error, {:invalid, [{\"--port\", \"nope\"}]}}\n\n    iex> {:ok, result} = parse([], [options: [lang: [default: \"elixir\"]]])\n    iex> result.options.lang\n    \"elixir\"\n\n    iex> {:ok, result} = parse([], [options: [lang: []]])\n    iex> Map.has_key?(result.options, :lang)\n    false\n\n    iex> {:ok, result} = parse([], options: [])\n    iex> result.options.help\n    false\n\n    iex> {:ok, result} = parse(~w(--help), options: [])\n    iex> result.options.help\n    true\n\n#","ref":"MixVersion.CLI.html#parse/2-options-examples"},{"type":"function","title":"Defining arguments - MixVersion.CLI.parse/2","doc":"Arguments can be defined in the same way, providing a `Keyword` where the\nkeys are the argument names and the values are the parameters.\n\n#","ref":"MixVersion.CLI.html#parse/2-defining-arguments"},{"type":"function","title":"Defining arguments - MixVersion.CLI.parse/2","doc":"The following parameters are available:\n\n- `:required` - A boolean marking the argument as required. **Note that\n  arguments are required by default**. Keys for optional arguments that\n  are not provided by the command line will not be defined in the results.\n- `:cast` - Accepts a fun or a `{module, function, arguments}` tuple to\n  transform the argument value when parsing. The invoked function must\n  return a result tuple: `{:ok, _} | {:error, _}`.\n- `:doc` - Accepts a string that will be used when formatting the usage\n  block for the command. Note that this is not currently implemented for\n  arguments.\n\n#","ref":"MixVersion.CLI.html#parse/2-defining-arguments"},{"type":"function","title":"Arguments examples - MixVersion.CLI.parse/2","doc":"iex> {:ok, result} = parse(~w(joe), arguments: [who: []])\n    iex> result.arguments.who\n    \"joe\"\n\n    iex> parse([], arguments: [who: []])\n    {:error, {:missing_argument, :who}}\n\n    iex> {:ok, result} = parse([], arguments: [who: [required: false]])\n    iex> result.arguments\n    %{}\n\n    iex> cast = fn string -> Date.from_iso8601(string) end\n    iex> {:ok, result} = parse([\"2022-12-22\"], arguments: [date: [cast: cast]])\n    iex> result.arguments.date\n    ~D[2022-12-22]\n\n    iex> cast = {Date, :from_iso8601, []}\n    iex> {:ok, result} = parse([\"2022-12-22\"], arguments: [date: [cast: cast]])\n    iex> result.arguments.date\n    ~D[2022-12-22]\n\n    iex> cast = {Date, :from_iso8601, []}\n    iex> parse([\"not-a-date\"], arguments: [date: [cast: cast]])\n    {:error, {:argument_cast, :date, :invalid_format}}","ref":"MixVersion.CLI.html#parse/2-arguments-examples"},{"type":"function","title":"MixVersion.CLI.parse_or_halt!/2","doc":"Attempts to parse the command line arguments `argv` with the defined\ncommand.\n\nCommand options and arguments are documented in the `parse/2` function of\nthis module.\n\nIn `parse_or_halt!/2`, the successful return value will not be wrapped in\nan `:ok` tuple, but directly a map with the `:options` and `:arguments`\nkeys.\n\nIn case of a parse error, this function will output the usage block\nfollowed by a formatted error message, and halt the Erlang runtime.","ref":"MixVersion.CLI.html#parse_or_halt!/2"},{"type":"function","title":"MixVersion.CLI.put_shell/1","doc":"Defines the current shell to send console messages to. Accepts either\n`MixVersion.CLI` or `MixVersion.CLI.ProcessShell`.\n\nThe shell is saved to `:persistent_term`, so shell should not be changed\nrepeatedly during runtime. This method of persistence is subject to change\nand should not be relied on.","ref":"MixVersion.CLI.html#put_shell/1"},{"type":"function","title":"MixVersion.CLI.shell/0","doc":"Returns the current shell used by MixVersion.CLI to send output.","ref":"MixVersion.CLI.html#shell/0"},{"type":"function","title":"MixVersion.CLI.success/1","doc":"Outputs `iodata` in the current shell, formatted with green color.","ref":"MixVersion.CLI.html#success/1"},{"type":"function","title":"MixVersion.CLI.warn/1","doc":"Outputs `iodata` to `stderr` in the current shell, formatted with yellow\ncolor.","ref":"MixVersion.CLI.html#warn/1"},{"type":"function","title":"MixVersion.CLI.writeln/1","doc":"Outputs `iodata` in the current shell.","ref":"MixVersion.CLI.html#writeln/1"},{"type":"module","title":"MixVersion.Config","doc":"Helpers to read from the Mix project the app is called in.","ref":"MixVersion.Config.html"},{"type":"function","title":"MixVersion.Config.current_project/0","doc":"","ref":"MixVersion.Config.html#current_project/0"},{"type":"function","title":"MixVersion.Config.otp_app/1","doc":"","ref":"MixVersion.Config.html#otp_app/1"},{"type":"function","title":"MixVersion.Config.project_get/1","doc":"","ref":"MixVersion.Config.html#project_get/1"},{"type":"function","title":"MixVersion.Config.project_get/2","doc":"","ref":"MixVersion.Config.html#project_get/2"},{"type":"function","title":"MixVersion.Config.project_get/3","doc":"","ref":"MixVersion.Config.html#project_get/3"},{"type":"module","title":"MixVersion.Git","doc":"This module is a simple, ad-hoc interface to the Git CLI.","ref":"MixVersion.Git.html"},{"type":"function","title":"MixVersion.Git.add/2","doc":"","ref":"MixVersion.Git.html#add/2"},{"type":"function","title":"MixVersion.Git.check_tag_availability/2","doc":"","ref":"MixVersion.Git.html#check_tag_availability/2"},{"type":"function","title":"MixVersion.Git.commit/2","doc":"","ref":"MixVersion.Git.html#commit/2"},{"type":"function","title":"MixVersion.Git.get_repo/1","doc":"","ref":"MixVersion.Git.html#get_repo/1"},{"type":"function","title":"MixVersion.Git.get_unstaged/1","doc":"","ref":"MixVersion.Git.html#get_unstaged/1"},{"type":"function","title":"MixVersion.Git.installed?/0","doc":"","ref":"MixVersion.Git.html#installed?/0"},{"type":"function","title":"MixVersion.Git.path_relative_to/2","doc":"","ref":"MixVersion.Git.html#path_relative_to/2"},{"type":"function","title":"MixVersion.Git.tag/3","doc":"","ref":"MixVersion.Git.html#tag/3"},{"type":"behaviour","title":"MixVersion.Stage","doc":"Behaviour for mix version stages.","ref":"MixVersion.Stage.html"},{"type":"callback","title":"MixVersion.Stage.applies?/1","doc":"","ref":"MixVersion.Stage.html#c:applies?/1"},{"type":"callback","title":"MixVersion.Stage.run/1","doc":"","ref":"MixVersion.Stage.html#c:run/1"},{"type":"module","title":"MixVersion.Stage.ApplyHook","doc":"Stage that creates a new Git commit with the updated `mix.exs` file and all\nother changes added to the Git index.","ref":"MixVersion.Stage.ApplyHook.html"},{"type":"function","title":"MixVersion.Stage.ApplyHook.applies?/1","doc":"","ref":"MixVersion.Stage.ApplyHook.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.ApplyHook.run/2","doc":"","ref":"MixVersion.Stage.ApplyHook.html#run/2"},{"type":"module","title":"MixVersion.Stage.CheckGitTag","doc":"Stage that checks that the future Git tag does not already exist.","ref":"MixVersion.Stage.CheckGitTag.html"},{"type":"function","title":"MixVersion.Stage.CheckGitTag.applies?/1","doc":"","ref":"MixVersion.Stage.CheckGitTag.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.CheckGitTag.run/1","doc":"","ref":"MixVersion.Stage.CheckGitTag.html#run/1"},{"type":"module","title":"MixVersion.Stage.CheckUnstaged","doc":"Checks if any file in the project has changes that are not committed to Git.\n\n* If the project's `mix.exs` file has unstagged changes, `mix version` will\n  abort, refusing to go any further.\n* If other files have changes, the app will prompt for confirmation to\n  continue.","ref":"MixVersion.Stage.CheckUnstaged.html"},{"type":"function","title":"MixVersion.Stage.CheckUnstaged.applies?/1","doc":"","ref":"MixVersion.Stage.CheckUnstaged.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.CheckUnstaged.run/1","doc":"","ref":"MixVersion.Stage.CheckUnstaged.html#run/1"},{"type":"module","title":"MixVersion.Stage.CommitChanges","doc":"Stage that creates a new Git commit with the updated `mix.exs` file and all\nother changes added to the Git index.","ref":"MixVersion.Stage.CommitChanges.html"},{"type":"function","title":"MixVersion.Stage.CommitChanges.applies?/1","doc":"","ref":"MixVersion.Stage.CommitChanges.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.CommitChanges.run/1","doc":"","ref":"MixVersion.Stage.CommitChanges.html#run/1"},{"type":"module","title":"MixVersion.Stage.DetectGitCommand","doc":"Stage that checks if the `git` command is callable with `System.cmd/3`.","ref":"MixVersion.Stage.DetectGitCommand.html"},{"type":"function","title":"MixVersion.Stage.DetectGitCommand.applies?/1","doc":"","ref":"MixVersion.Stage.DetectGitCommand.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.DetectGitCommand.run/1","doc":"","ref":"MixVersion.Stage.DetectGitCommand.html#run/1"},{"type":"module","title":"MixVersion.Stage.FindGitRepo","doc":"Finds the root path of the Git repository of the project, if any.","ref":"MixVersion.Stage.FindGitRepo.html"},{"type":"function","title":"MixVersion.Stage.FindGitRepo.applies?/1","doc":"","ref":"MixVersion.Stage.FindGitRepo.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.FindGitRepo.run/1","doc":"","ref":"MixVersion.Stage.FindGitRepo.html#run/1"},{"type":"module","title":"MixVersion.Stage.GetNextVsn","doc":"Decides on the new version number from the passed CLI options.","ref":"MixVersion.Stage.GetNextVsn.html"},{"type":"function","title":"MixVersion.Stage.GetNextVsn.applies?/1","doc":"","ref":"MixVersion.Stage.GetNextVsn.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.GetNextVsn.bump/2","doc":"","ref":"MixVersion.Stage.GetNextVsn.html#bump/2"},{"type":"function","title":"MixVersion.Stage.GetNextVsn.run/1","doc":"","ref":"MixVersion.Stage.GetNextVsn.html#run/1"},{"type":"module","title":"MixVersion.Stage.PrintAndStop","doc":"This stage checks for the output command and prints the version and exists if\nthe flag is provided.","ref":"MixVersion.Stage.PrintAndStop.html"},{"type":"function","title":"MixVersion.Stage.PrintAndStop.applies?/1","doc":"","ref":"MixVersion.Stage.PrintAndStop.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.PrintAndStop.run/1","doc":"","ref":"MixVersion.Stage.PrintAndStop.html#run/1"},{"type":"module","title":"MixVersion.Stage.TagGitHead","doc":"Stage that creates a possibly annotated tag at the current Git HEAD.","ref":"MixVersion.Stage.TagGitHead.html"},{"type":"function","title":"MixVersion.Stage.TagGitHead.applies?/1","doc":"","ref":"MixVersion.Stage.TagGitHead.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.TagGitHead.run/1","doc":"","ref":"MixVersion.Stage.TagGitHead.html#run/1"},{"type":"function","title":"MixVersion.Stage.TagGitHead.tag_name/1","doc":"","ref":"MixVersion.Stage.TagGitHead.html#tag_name/1"},{"type":"module","title":"MixVersion.Stage.UpdateMixfile","doc":"Stage that is responsible to write the `mix.exs` file with the new version\nnumber.","ref":"MixVersion.Stage.UpdateMixfile.html"},{"type":"function","title":"MixVersion.Stage.UpdateMixfile.applies?/1","doc":"","ref":"MixVersion.Stage.UpdateMixfile.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.UpdateMixfile.git_enabled?/1","doc":"","ref":"MixVersion.Stage.UpdateMixfile.html#git_enabled?/1"},{"type":"function","title":"MixVersion.Stage.UpdateMixfile.run/1","doc":"","ref":"MixVersion.Stage.UpdateMixfile.html#run/1"},{"type":"module","title":"MixVersion.SysCmd","doc":"Utiliy to run `System.cmd/3` with `:ok/:error` tuples results.","ref":"MixVersion.SysCmd.html"},{"type":"function","title":"MixVersion.SysCmd.exec/3","doc":"","ref":"MixVersion.SysCmd.html#exec/3"},{"type":"module","title":"MixVersion.Token","doc":"The \"token\" is the state of the command line execution, passed to and returned\nfrom all stages.","ref":"MixVersion.Token.html"},{"type":"function","title":"MixVersion.Token.new/3","doc":"","ref":"MixVersion.Token.html#new/3"},{"type":"function","title":"MixVersion.Token.put_current_vsn/2","doc":"","ref":"MixVersion.Token.html#put_current_vsn/2"},{"type":"function","title":"MixVersion.Token.put_git_cmd?/2","doc":"","ref":"MixVersion.Token.html#put_git_cmd?/2"},{"type":"function","title":"MixVersion.Token.put_git_repo/2","doc":"","ref":"MixVersion.Token.html#put_git_repo/2"},{"type":"function","title":"MixVersion.Token.put_hooks/2","doc":"","ref":"MixVersion.Token.html#put_hooks/2"},{"type":"function","title":"MixVersion.Token.put_next_vsn/2","doc":"","ref":"MixVersion.Token.html#put_next_vsn/2"},{"type":"function","title":"MixVersion.Token.put_opts/2","doc":"","ref":"MixVersion.Token.html#put_opts/2"},{"type":"type","title":"MixVersion.Token.t/0","doc":"","ref":"MixVersion.Token.html#t:t/0"}],"content_type":"text/markdown"}